/* GLSL_DoF2: Depth of Field effect with GLSL shaders and FBOs
   Copyright (C) 2008 Angelo "Encelo" Theodorou
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.
 
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
  
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/


#include <stdio.h>
#include <stdlib.h>

#include <SDL/SDL.h>
#include <GL/gl.h>
#include <GL/glext.h> 

	
int FrameTiming(void)
{
	Uint32 interval;
	static Uint32 current, last = 0, five = 0, nframes = 0;

	current = SDL_GetTicks();
	nframes++;

	if (current - five > 5*1000) {
		printf("%u frames in 5 seconds = %.1f FPS\n", nframes, (float)nframes/5.0f);
		nframes = 0;
		five = current;
	}
	
	interval = current - last;
	last = current;
	
	return interval;
}


void printObjectInfoLog(GLuint obj)
{
	int infologLength = 0;
	int charsWritten  = 0;
	char *infoLog;

	if (glIsShader(obj) == GL_TRUE)
		glGetShaderiv(obj, GL_INFO_LOG_LENGTH, &infologLength);
	else
		glGetProgramiv(obj, GL_INFO_LOG_LENGTH, &infologLength);

	if (infologLength > 1) {
		infoLog = (char *)malloc(infologLength);
		if (glIsShader(obj) == GL_TRUE) {
			glGetShaderInfoLog(obj, infologLength, &charsWritten, infoLog);
			printf("Shader InfoLog: %s\n", infoLog);
		}
		else {
			glGetProgramInfoLog(obj, infologLength, &charsWritten, infoLog);
			printf("Program InfoLog: %s\n", infoLog);
		}
		free(infoLog);
	}
}


void DrawCube(int open)
{
	glBegin(GL_QUADS);
		if (!open) {
		/* Front Face */
		glTexCoord2f(1.0f, 1.0f);
		glVertex3f(-1.0f, -1.0f,  1.0f);
		glTexCoord2f(0.0f, 1.0f);
		glVertex3f( 1.0f, -1.0f,  1.0f);
		glTexCoord2f(0.0f, 0.0f);
		glVertex3f( 1.0f,  1.0f,  1.0f);
		glTexCoord2f(1.0f, 0.0f);
		glVertex3f(-1.0f,  1.0f,  1.0f);
		}
		/* Back Face */
		glTexCoord2f(0.0f, 1.0f);
		glVertex3f(-1.0f, -1.0f, -1.0f);
		glTexCoord2f(0.0f, 0.0f);
		glVertex3f(-1.0f,  1.0f, -1.0f);
		glTexCoord2f(1.0f, 0.0f);
		glVertex3f( 1.0f,  1.0f, -1.0f);
		glTexCoord2f(1.0f, 1.0f);
		glVertex3f( 1.0f, -1.0f, -1.0f);
		if (!open) {
		/* Top Face */
		glTexCoord2f(1.0f, 0.0f);
		glVertex3f(-1.0f,  1.0f, -1.0f);
		glTexCoord2f(1.0f, 1.0f);
		glVertex3f(-1.0f,  1.0f,  1.0f);
		glTexCoord2f(0.0f, 1.0f);
		glVertex3f( 1.0f,  1.0f,  1.0f);
		glTexCoord2f(0.0f, 0.0f);
		glVertex3f( 1.0f,  1.0f, -1.0f);
		}
		/* Bottom Face */
		glTexCoord2f(0.0f, 0.0f);
		glVertex3f(-1.0f, -1.0f, -1.0f);
		glTexCoord2f(1.0f, 0.0f);
		glVertex3f( 1.0f, -1.0f, -1.0f);
		glTexCoord2f(1.0f, 1.0f);
		glVertex3f( 1.0f, -1.0f,  1.0f);
		glTexCoord2f(0.0f, 1.0f);
		glVertex3f(-1.0f, -1.0f,  1.0f);
		// Right face
		glTexCoord2f(0.0f, 1.0f);
		glVertex3f( 1.0f, -1.0f, -1.0f);
		glTexCoord2f(0.0f, 0.0f);
		glVertex3f( 1.0f,  1.0f, -1.0f);
		glTexCoord2f(1.0f, 0.0f);
		glVertex3f( 1.0f,  1.0f,  1.0f);
		glTexCoord2f(1.0f, 1.0f);
		glVertex3f( 1.0f, -1.0f,  1.0f);
		// Left Face
		glTexCoord2f(1.0f, 1.0f);
		glVertex3f(-1.0f, -1.0f, -1.0f);
		glTexCoord2f(0.0f, 1.0f);
		glVertex3f(-1.0f, -1.0f,  1.0f);
		glTexCoord2f(0.0f, 0.0f);
		glVertex3f(-1.0f,  1.0f,  1.0f);
		glTexCoord2f(1.0f, 0.0f);
		glVertex3f(-1.0f,  1.0f, -1.0f);
	glEnd();
}
